@@ -37,11 +37,11 @@ App::GitHooks - Extensible plugins system for git hooks.
 
 =head1 VERSION
 
-Version 1.5.1
+Version 1.6.0
 
 =cut
 
-our $VERSION = '1.5.1';
+our $VERSION = '1.6.0';
 
 
 =head1 DESCRIPTION
@@ -881,6 +881,24 @@ sub get_success_character
 }
 
 
+=head2 get_warning_character()
+
+Return a character to use to indicate a warning.
+
+	my $warning_character = $app->get_warning_character()
+
+=cut
+
+sub get_warning_character
+{
+	my ( $self ) = @_;
+
+	return $self->get_terminal()->is_utf8()
+		? "\x{26A0}"
+		: "!";
+}
+
+
 =head2 get_staged_changes()
 
 Return a C<App::GitHooks::StagedChanges> object corresponding to the changes
