@@ -35,11 +35,11 @@ App::GitHooks::Plugin::Test::CustomReply - A test plugin that allows specifying
 
 =head1 VERSION
 
-Version 1.5.1
+Version 1.6.0
 
 =cut
 
-our $VERSION = '1.5.1';
+our $VERSION = '1.6.0';
 
 our $HOOK_REPLIES;
 
@@ -137,7 +137,7 @@ foreach my $hook ( @$App::GitHooks::Plugin::SUPPORTED_SUBS )
 		croak "No return value specified for >$hook<."
 			if $return !~ /\w/;
 		croak "The return value for >$hook< in the [Test::CustomReply] section of the .githooksrc is not valid."
-			if $return !~ /^PLUGIN_RETURN_(?:FAILED|PASSED|SKIPPED)$/x;
+			if $return !~ /^PLUGIN_RETURN_(?:FAILED|PASSED|WARNED|SKIPPED)$/x;
 
 		return ${$return};
 	};
